// Scilab code for 
// The paradoxes hidden behind the Droop model highlighted by a metabolic approach
// by C Baroukh, F Mairet and O Bernard 
//
// Adapted from Baroukh et al (Plos One, 2014)
//
// Simulations of the day-night cycles

clear 
xdel(winsid())//close all figure windows

MODEL=1// To choose the model: 0=w/oEx(*); 1=Ex_CARB; 2=Ex_G6P; 3=Ex_PEP; 4=Ex_GAP; 

//////////////////////////////////////////////////
///////////Simulation parameters ////////////////
//////////////////////////////////////////////////

t0=5; // days before first measurement
t_step = 0.01 //h
t_step_export = 0.2 //h;
 
//params = [effmax k_g6p_from_gap  k_gap_from_g6p  k_carb  k_carbr  k_pa  k_par  k_pep  k_pepr  kbiom kexc ];

select MODEL
case 0 then
  //   params=[  0.0012967   204.84559   0.2160986   16.843273   0.   55.889121   0.0392724   8104.0145   11.880252   11548.722 ] ; //  w/oEx 
       params=[ 0.0011011   62.582543   0.   13.472625   0.   141.40216   0.0431291   7707.7269   321.34625   317439.86];  // w/oEx* 
  case 1 then 
       params=[  0.0016079   6.0726315   0.0921596   13.609136   0.   0.783336   0.1202538   7964.8668   547.39568   2889.2591   0.0778283  ];
  case 2 then
       params=[  0.0021185   3.3175869   0.   46.222195   1.2162263   0.4128736   0.1167988   347.1997   121.54694   1335.7956   5.8980956 ];
  case 3 then         
       params=[    0.0045   569.20568   3.0372364   13376.282   376.41236   108.01982   0.090034   5169.46   0.   2028.0569   7.2933079  ];
  case 4 then
       params=[  0.0041455   0.5895331   2.6190586   402.83913   16.384763   0.0966455   0.1056239   26.229641   36.223695   1168.0651   3.4703291 ]; 
end

//////////////////////////////////////////////////
///////////Data import////////////////////////////
//////////////////////////////////////////////////

[fd,SST,Sheetnames,Sheetpos] = xls_open('Data_Tiso.xls');
[Value,TextInd] = xls_read(fd,Sheetpos(1));
mclose(fd);
col_tBIOM = 1;
col_dBIOM = 2;
col_tBIOM2 = 3;
col_dBIOM2 = 4;
col_tN = 9;
col_dN = 10;
col_tN2 = 11;
col_dN2 = 12;
col_tS = 13;
col_dS = 14;
col_tS2 = 15;
col_dS2 = 16;
col_tChl = 17;
col_dChl = 18;
col_tChl2 = 19;
col_dChl2 = 20;
col_tCARB = 21;
col_dCARB = 22;
col_tCARB2 = 23;
col_dCARB2 = 24;
col_tPA = 25;
col_dPA = 26;
col_tPA2 = 27;
col_dPA2 = 28;
col_tD = 29;
col_dD = 30;
col_tD2 = 31;
col_dD2 = 32;
col_tI = 33;
col_dI = 34;
col_tSin = 35;
col_dSin = 36;
col_tSin2 = 37;
col_dSin2 = 38;

// Get data
t_BIOM = thrownan(Value(:,col_tBIOM))+t0;
d_BIOM = thrownan(Value(:,col_dBIOM));
t_BIOM2 = thrownan(Value(:,col_tBIOM2))+t0;
d_BIOM2 = thrownan(Value(:,col_dBIOM2));
t_N = thrownan(Value(:,col_tN))+t0;
d_N = thrownan(Value(:,col_dN));
t_N2 = thrownan(Value(:,col_tN2))+t0;
d_N2 = thrownan(Value(:,col_dN2));
t_S = thrownan(Value(:,col_tS))+t0;
d_S = thrownan(Value(:,col_dS));
t_S2 = thrownan(Value(:,col_tS2))+t0;
d_S2 = thrownan(Value(:,col_dS2));
t_Chl = thrownan(Value(:,col_tChl))+t0;
d_Chl = thrownan(Value(:,col_dChl));
t_Chl2 = thrownan(Value(:,col_tChl2))+t0;
d_Chl2 = thrownan(Value(:,col_dChl2));
t_CARB = thrownan(Value(:,col_tCARB))+t0;
d_CARB = thrownan(Value(:,col_dCARB));
t_CARB2 = thrownan(Value(:,col_tCARB2))+t0;
d_CARB2 = thrownan(Value(:,col_dCARB2));
t_PA = thrownan(Value(:,col_tPA))+t0;
d_PA = thrownan(Value(:,col_dPA));
t_PA2 = thrownan(Value(:,col_tPA2))+t0;
d_PA2 = thrownan(Value(:,col_dPA2));
t_D = thrownan(Value(:,col_tD))+t0;
d_D = thrownan(Value(:,col_dD));
t_D2 = thrownan(Value(:,col_tD2))+t0;
d_D2 = thrownan(Value(:,col_dD2));
t_I = thrownan(Value(:,col_tI))+t0;
d_I = thrownan(Value(:,col_dI));
t_Sin = thrownan(Value(:,col_tSin))+t0;
d_Sin = thrownan(Value(:,col_dSin));
t_Sin2 = thrownan(Value(:,col_tSin2))+t0;
d_Sin2 = thrownan(Value(:,col_dSin2));

//////////////// Experimental data (dilution rate, light, nutrient input)

t_intervals = [12 12 12 12 12 12 12 12 12 12 12.0 12.0 0.8599992 11.140001 12.0 12.0 7.2575 4.7425 1.2572222 10.742778 12.0 4.7888889 7.2111111 6.7888889 5.2111111 12.0 1.44 0.024 0.5626656 0.7725011 9.2008333 2.9477778 6.0005556 3.0516667 10.669444 1.3305556 12.0 12.0 1.3561111 10.643889];
Ds=[0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.0416667 0.01375 0.01375 0.0045833 0.0045833 0.0045833 0.0054167 0.0054167 0.0 0.0 0.0 0.0 0.0 0.0 0.0270833 0.0270833 0.025 0.0208333 0.0208333 0.0270833 0.0270833 0.0270833 0.0270833 0.0408333];
Sins=[0.287 0.287  0.287 0.287  0.287 0.287  0.287 0.287 0.287 0.287 0.287 0.287 0.287 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.286 0.286 0.286 0.286 0.286 0.286 0.286 0.286 0.286 0.286 0.286];
intensite_maxs=[0.0 1330.8961 0.0 1330.8961 0.0 1330.8961 0.0 1330.8961 0.0 1330.8961 0.0 1330.8961 0.0 0.0 1230.8961 0.0 1390.8961 1390.8961 0.0 0.0 1430.8961 0.0 0.0 1510.8961 1510.8961 0.0 1590.8961 1590.8961 1590.8961 1590.8961 1590.8961 0.0 0.0 0.0 1390.8961 1390.8961 0.0 1390.8961 0.0 0.0];

Sin_impulses = [0 0 0 0 0 0 0 0 0 0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 1.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0 0.0];

//////////////////////////////////////////////////
///////////Metabolic network//////////////////////
//////////////////////////////////////////////////

M_N = 14;
M_C = 12;

//metabolites
GAP = 1;
CARB = 2;
PEP = 3;
PA = 4;
G6P = 5;
NO3 = 6;
EPS=7;
ACE=8;
GLYC=9;
BIOMf = 10;
BIOM = 11;

//metabolite names
names_m(GAP)="GAP";
names_m(CARB)="CARB";
names_m(PEP)="PEP";
names_m(PA)="PA";
names_m(G6P)="G6P";
names_m(NO3)="NO3";
names_m(EPS)="EPS";
names_m(ACE)="ACE";
names_m(GLYC)="CLYC";
names_m(BIOMf)="BIOMf";
names_m(BIOM)="BIOM";

//number of Carbon atoms per molecule
nb_C(GAP)=3;
nb_C(CARB)=6;
nb_C(PEP)=3;
nb_C(PA)=36.2;
nb_C(G6P)=6;
nb_C(NO3)=0;
nb_C(BIOMf)=8.59;
nb_C(BIOM)=1;

nb_C(GLYC)=3;
nb_C(ACE)=2;
nb_C(EPS)=6;

//number of Azote atoms per molecule
nb_N(GAP)=0;
nb_N(CARB)=0;
nb_N(PEP)=0;
nb_N(PA)=0;
nb_N(G6P)=0;
nb_N(NO3)=1;
nb_N(BIOMf)=1.27;
nb_N(BIOM)=1;

//number of metabolites
nb_metabolites = size(names_m,1);

//reactions
r_photo = 1; //30 Light + 3 CO2 + 2 H2O + Pi --> GAP + 3 O2 (1)
r_g6p_from_gap = 2; //2 GAP + H2O --> Pi + G6P (2)
r_gap_from_g6p = 3; //ATP + G6P --> H + ADP + 2 GAP (3)
r_carb = 4; //G6P <--> CARB + Pi (4)
r_pa = 5; //34.382 H + 29.228 NADPH + 16.614 PEP + 13.46 NAD + 2.154 O2 + 2 ADP + 1 GAP <--> 1 PA + 2 ATP + 4.308 H2O + 13.46 NADH + 14.614 Pi + 16.614 CO2 + 29.228 NADP (5)
r_pep = 6; //1 Pi + 1 ADP + 1 GAP + 1 NAD --> 1 H + 1 ATP + 1 NADH + 1 H2O + 1 PEP (6)
r_biom = 7; //7.36572 O2 + 4.45869 H + 3.1265 PEP + 1.30971 NO3 + 1.14172 G6P + 0.1118 PA + 0.0303876 SO4 + 0.0025 Mg2 --> 1 Biomass + 4.22672 Pi + 6.00312 H2O + 11.6706 CO2 (7)
r_exc = 8; //excretion

//reactions names
names_r(r_photo)="Photosynthesis";
names_r(r_g6p_from_gap)="G6P to GAP";
names_r(r_gap_from_g6p)="GAP to G6P";
names_r(r_carb)="Carbohydrates synthesis";
names_r(r_pa)="Lipids synthesis";
names_r(r_pep)="Lower glycolysis";
names_r(r_biom)="Biomasse synthesis";
names_r(r_exc)="Excretion";

//Number of reactions
nb_reactions = size(names_r,1);

//stoichiometric matrix
Stoich_mat = zeros(nb_metabolites,nb_reactions);

//30 Light + 3 CO2 + 2 H2O + Pi --> GAP + 3 O2 (1)
Stoich_mat(GAP,r_photo)= 1;

//2 GAP + H2O --> Pi + G6P (2)
Stoich_mat(GAP,r_g6p_from_gap)= -2;
Stoich_mat(G6P,r_g6p_from_gap)= 1;

//ATP + G6P --> H + ADP + 2 GAP (3)
Stoich_mat(G6P,r_gap_from_g6p)= -1;
Stoich_mat(GAP,r_gap_from_g6p)= 2;

//G6P <--> CARB + Pi (4)
Stoich_mat(G6P,r_carb)= -1;
Stoich_mat(CARB,r_carb)= 1;

//34.382 H + 29.228 NADPH + 16.614 PEP + 13.46 NAD + 2.154 O2 + 2 ADP + 1 GAP <--> 1 PA + 2 ATP + 4.308 H2O + 13.46 NADH + 14.614 Pi + 16.614 CO2 + 29.228 NADP (5)
Stoich_mat(GAP,r_pa)= -1;
Stoich_mat(PEP,r_pa)= -16.614;
Stoich_mat(PA,r_pa)= 1;

//1 Pi + 1 ADP + 1 GAP + 1 NAD --> 1 H + 1 ATP + 1 NADH + 1 H2O + 1 PEP (6)
Stoich_mat(GAP,r_pep)= -1;
Stoich_mat(PEP,r_pep)= 1;

//7.36572 O2 + 4.45869 H + 3.1265 PEP + 1.30971 NO3 + 1.14172 G6P + 0.1118 PA + 0.0303876 SO4 + 0.0025 Mg2 --> 1 Biomass + 4.22672 Pi + 6.00312 H2O + 11.6706 CO2 (7)
Stoich_mat(G6P,r_biom)= -1.14172;
Stoich_mat(NO3,r_biom)= -1.30971;
Stoich_mat(PEP,r_biom)= -3.1265;
Stoich_mat(PA,r_biom)= -0.1118;
Stoich_mat(BIOMf,r_biom)= 1;

// Excretion
select MODEL
  case 1 then 
    Stoich_mat(CARB,r_exc)=-1;
    Stoich_mat(EPS,r_exc)=1;
  case 2 then
    Stoich_mat(G6P,r_exc)=-1;
    Stoich_mat(EPS,r_exc)=1;      
  case 3 then
    Stoich_mat(PEP,r_exc)=-1;
    Stoich_mat(ACE,r_exc)=1;      
  case 4 then
    Stoich_mat(GAP,r_exc)=-1;
    Stoich_mat(GLYC,r_exc)=1;    
      case 5 then 
    Stoich_mat(CARB,r_exc)=-1;
    Stoich_mat(EPS,r_exc)=1;
  case 6 then
    Stoich_mat(G6P,r_exc)=-1;
    Stoich_mat(EPS,r_exc)=1;      
  case 7 then
    Stoich_mat(PEP,r_exc)=-1;
    Stoich_mat(ACE,r_exc)=1;      
  case 8 then
    Stoich_mat(GAP,r_exc)=-1;
    Stoich_mat(GLYC,r_exc)=1;  
end

//////////////////////////////////////////////////
///////////Initial conditions/////////////////////
//////////////////////////////////////////////////
Ksi01=zeros(nb_metabolites,1);

Ksi01(BIOM) = 28.5/M_C;

Ksi01(GAP) = 0.0006/nb_C(GAP);
Ksi01(CARB) = 0.37*Ksi01(BIOM)/nb_C(CARB);
Ksi01(PEP) = 0.004/nb_C(PEP);
Ksi01(PA) = 0.20*Ksi01(BIOM)/nb_C(PA);
Ksi01(G6P) = 0.03/nb_C(G6P);
Ksi01(NO3) = 1.6/(nb_N(NO3)*M_N);
Ksi01(BIOMf) = (Ksi01(BIOM)-Ksi01(PA)*nb_C(PA)-Ksi01(CARB)*nb_C(CARB))/(nb_C(BIOMf));

Ksi01(EPS)=0;
Ksi01(ACE)=0;
Ksi01(GLYC)=0;

//////////////////////////////////////////////////
/////////Differential equations model////////////
////////////////////////////////////////////////

//ODE system
function Ksidot=DRUM(t, Ksi)  
       //kinetics
    rates = zeros(nb_reactions,1);

    //r_light
    eff_max =  params(1);
    rates(r_photo) = eff_max*intensite_max*sin(%pi*(t-floor(t/12)*12)/(12))^2;
    
    //r_g6p_from_gap
    k_g6p_from_gap = params(2);
    rates(r_g6p_from_gap) = k_g6p_from_gap*Ksi(GAP)/Ksi(BIOMf);
    
    //r_gap_from_g6p
    k_gap_from_g6p = params(3);
    rates(r_gap_from_g6p) = k_gap_from_g6p*Ksi(G6P)/Ksi(BIOMf);
    
    //r_carb
    k_carb = params(4); //h-1
    k_carb_r = params(5); //h-1
    rates(r_carb) = k_carb*Ksi(G6P)/Ksi(BIOMf) - k_carb_r*Ksi(CARB)/Ksi(BIOMf);
    
    //r_pa
    k_pa = params(6);//mmol-1.B.h-1
    k_par = params(7);//h-1
    rates(r_pa) = k_pa*Ksi(GAP)/Ksi(BIOMf)*Ksi(PEP)/Ksi(BIOMf) - k_par*Ksi(PA)/Ksi(BIOMf);
 
    //r_pep
    k_pep = params(8);//h-1
    k_pepr = params(9); //h-1
    rates(r_pep) = k_pep*Ksi(GAP)/Ksi(BIOMf) - k_pepr*Ksi(PEP)/Ksi(BIOMf);
    
    //r_biom
    k_biom = params(10);
    rates(r_biom) = k_biom*Ksi(PEP)/Ksi(BIOMf)*Ksi(G6P)/Ksi(BIOMf)*Ksi(NO3)*Ksi(PA)/Ksi(BIOMf);

    //r_exc
select MODEL
case 1 then 
    k_exc=params(11);
    rates(r_exc)=k_exc*Ksi(CARB)/Ksi(BIOMf);
case 2 then
    k_exc=params(11);
    rates(r_exc)=k_exc*Ksi(G6P)/Ksi(BIOMf);    
case 3 then
    k_exc=params(11);
    rates(r_exc)=k_exc*Ksi(PEP)/Ksi(BIOMf);   
case 4 then
    k_exc=params(11);
    rates(r_exc)=k_exc*Ksi(GAP)/Ksi(BIOMf);
end

    Ksidot(1:BIOM-1) = Stoich_mat(1:BIOM-1,:)*rates*Ksi(BIOMf) - D*Ksi(1:BIOM-1) ;
    Ksidot(BIOM) = nb_C(BIOMf)*Ksidot(BIOMf) + nb_C(CARB)*Ksidot(CARB) + nb_C(PA)*Ksidot(PA) + nb_C(GAP)*Ksidot(GAP) + nb_C(G6P)*Ksidot(G6P)+ nb_C(PEP)*Ksidot(PEP);
    Ksidot(NO3) = Stoich_mat(NO3,:)*rates*Ksi(BIOMf) - D*Ksi(NO3) + D*Sin;

endfunction  

//Solve the ODE system
t_start = 0;
t_end = t_intervals(1);
t = t_start:t_step:t_end;

Ksi0 = Ksi01;
D = Ds(1);
Sin = Sins(1);
intensite_max = intensite_maxs(1);

Ksi=ode(Ksi0,t_start,t,list(DRUM))

Ksis = Ksi;
ts = t;

for i=2:size(t_intervals,2)
   t_start = t_start + t_intervals(i-1);
   t_end = t_end + t_intervals(i);
   t = t_start:t_step:t_end;
    
   Ksi0 = Ksis(:,size(Ksis,2));
   D = Ds(i);
   Sin = Sins(i);
   intensite_max = intensite_maxs(i);
   
   if (Sin_impulses(i)>0) then
        Ksi0(NO3)=2.7/(nb_N(NO3)*M_N);
   end
    
   Ksi=ode(Ksi0,t_start,t,list(DRUM)) 
   
   Ksis = [Ksis,Ksi]; 
   ts = [ts,t];
end

//Compute annex variables to ODE system
Chl = Ksis(BIOMf,:)*2169.16; //Chl is proportional to functional biomass

////////////////////////////////////////////////////
//////////////////////Plots/////////////////////////
////////////////////////////////////////////////////

figure("Figure_name", "Simulation DRUM","BackgroundColor",[1,1,1]);
clf()

subplot(324)
plot(0,0,'k.')
mm=0.6;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0,Ksis(CARB,:)./Ksis(BIOM,:)*nb_C(CARB))
plot(t_CARB-t0,d_CARB,'kv');
plot(t_CARB2-t0,d_CARB2,'k^');
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Carbohydrate quota (g C/g C)";
aa.x_label.text="time (d)";

subplot(322)
plot(0,0,'k.')
mm=0.35;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0,Ksis(PA,:)./Ksis(BIOM,:)*nb_C(PA))
plot(t_PA-t0,d_PA,'kv');
plot(t_PA2-t0,d_PA2,'k^');
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Neutral lipid quota (g C/g C)";
aa.x_label.text="time (d)";

subplot(321)
plot(0,0,'k.')
mm=60;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0,Ksis(BIOM,:)*nb_C(BIOM)*M_C)
plot(t_BIOM-t0, d_BIOM,'kv');
plot(t_BIOM2-t0, d_BIOM2,'k^');
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Biomass (mg C/L)";
aa.x_label.text="time (d)";

subplot(323)
plot(0,0,'k.')
mm=4;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0,(Ksis(BIOMf,:)*nb_N(BIOMf)*M_N))
plot(t_N-t0, d_N,'kv');
plot(t_N2-t0, d_N2,'k^');
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Particulate nitrogen (mg N/L)";
aa.x_label.text="time (d)";

subplot(325)
plot(0,0,'k.')
mm=3;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0, Ksis(NO3,:)*nb_N(NO3)*14)
plot(t_S-t0,d_S,'kv')
plot(t_S2-t0,d_S2,'k^')
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Nitrate (mg/L)";
aa.x_label.text="time (d)";

subplot(326)
plot(0,0,'k.')
mm=500;
for k=0:8
xfrect(k,mm,0.5,mm)
gce().background = color("light grey");
end
plot2d(ts/24-t0,Chl);
plot(t_Chl-t0, d_Chl,'kv');
plot(t_Chl2-t0, d_Chl2,'k^');
aa=gca();
aa.tight_limits='on';
replot([0 %nan 8.5 %nan])
aa.y_label.text="Chlorophyll (µg/L)";
aa.x_label.text="time (d)";

///////// Rates computation for plotting

rates=[];
rates_C=[];

t_intervals_cumul(1) = t_intervals(1);
for (i=2:size(t_intervals,2))
    t_intervals_cumul(i) = t_intervals(i)+t_intervals_cumul(i-1);
end

for (i=1:size(ts,2))
    j = find(ts(i)<=t_intervals_cumul,1);
    light_intensity(i) = intensite_maxs(j)*sin(%pi*(ts(i)-floor(ts(i)/12)*12)/(12))^2;
end


 eff_max = params(1);
rates(r_photo,:) = eff_max'.*light_intensity;
rates_C(r_photo,:) = 3*rates(r_photo,:);

rates(r_g6p_from_gap,:) = params(2)*Ksis(GAP,:)./Ksis(BIOMf,:);
rates_C(r_g6p_from_gap,:) =6* rates(r_g6p_from_gap,:);

rates(r_gap_from_g6p,:) = params(3)*Ksis(G6P,:)./Ksis(BIOMf,:);
rates_C(r_gap_from_g6p,:) = 6*rates(r_gap_from_g6p,:);

rates(r_carb,:) = params(4)*Ksis(G6P,:)./Ksis(BIOMf,:) - params(5)*Ksis(CARB,:)./Ksis(BIOMf,:);
rates_C(r_carb,:) = 6*rates(r_carb,:);

rates(r_pa,:) = params(6)*Ksis(GAP,:)./Ksis(BIOMf,:).*Ksis(PEP,:)./Ksis(BIOMf,:) - params(7)*Ksis(PA,:)./Ksis(BIOMf,:);
rates_C(r_pa,:) = 36.2*rates(r_pa,:);
 
rates(r_pep,:) = params(8)*Ksis(GAP,:)./Ksis(BIOMf,:) - params(9)*Ksis(PEP,:)./Ksis(BIOMf,:);
rates_C(r_pep,:) = 3*rates(r_pep,:);

rates(r_biom,:) = params(10)*Ksis(PEP,:)./Ksis(BIOMf,:).*Ksis(G6P,:)./Ksis(BIOMf,:).*Ksis(PA,:)./Ksis(BIOMf,:).*Ksis(NO3,:);
rates_C(r_biom,:) = nb_C(BIOMf)*rates(r_biom,:);
  
select MODEL
 case 0 then 
    rates(r_exc,:)=0*Ksis(CARB,:);
    rates_C(r_exc,:) = 0*rates(r_exc,:); 
case 1 then 
    k_exc=params(11);
    rates(r_exc,:)=k_exc*Ksis(CARB,:)./Ksis(BIOMf,:);
    rates_C(r_exc,:) = 6*rates(r_exc,:);
case 2 then
    k_exc=params(11);
    rates(r_exc,:)=k_exc*Ksis(G6P,:)./Ksis(BIOMf,:);   
    rates_C(r_exc,:) =6* rates(r_exc,:);
case 3 then
    k_exc=params(11);
    rates(r_exc,:)=k_exc*Ksis(PEP,:)./Ksis(BIOMf,:);   
    rates_C(r_exc,:) = 3*rates(r_exc,:);
case 4 then
    k_exc=params(11);
    rates(r_exc,:)=k_exc*Ksis(GAP,:)./Ksis(BIOMf,:);
    rates_C(r_exc,:) = 3*rates(r_exc,:);
end


///  Plot Rates
figure("Figure_name", "Simulation DRUM Rates","BackgroundColor",[1,1,1]);
clf()

subplot(224)
mm=4;
for k=0:8
xfrect(k,mm,0.5,mm+1.5)
gce().background = color("light grey");
end
plot([0 9], [0 0],'k')
plot(ts/24-t0,rates_C(r_carb,:))
a9=gca();
a9.tight_limits='on';
replot([0 -1.5 8.5 4])
a9.y_label.text="Carbohydrate production rate (mol C h-1.mol B-1)";
a9.x_label.text="time (d)";

subplot(222)
mm=3;
for k=0:8
xfrect(k,mm,0.5,mm+1.5)
gce().background = color("light grey");
end
plot([0 9], [0 0],'k')
plot(ts/24-t0,rates_C(r_pa,:))
a9=gca();
a9.tight_limits='on';
replot([0 -1.5 8.5 3])
a9.y_label.text="Neutral lipid production rate (mol C h-1.mol B-1)";
a9.x_label.text="time (d)";

subplot(223)
plot([0 9], [0 0],'k')
mm=16;
for k=0:8
xfrect(k,mm,0.5,mm+1)
gce().background = color("light grey");
end
plot(ts/24-t0,rates_C(r_exc,:))
a9=gca();
a9.tight_limits='on';
replot([0 0 8.5 16])
a9.y_label.text="Excretion rate (mol C h-1.mol B-1)";
a9.x_label.text="time (d)";

subplot(221)
plot([0 9], [0 0],'k')
mm=22;
for k=0:8
xfrect(k,mm,0.5,mm+1)
gce().background = color("light grey");
end
plot(ts/24-t0,rates_C(r_photo,:))
a9=gca();
a9.tight_limits='on';
replot([0 0 8.5 22])
a9.y_label.text="Photosynthetic rate (mol C h-1.mol B-1)";
a9.x_label.text="time (d)";





